@@ -1,9 +1,10 @@
+# frozen_string_literal: true
+
 require 'librarian/resolver'
 
 module Librarian
   module Puppet
     class Resolver < Librarian::Resolver
-
       class Implementation < Librarian::Resolver::Implementation
         def sourced_dependency_for(dependency)
           return dependency if dependency.source
@@ -14,7 +15,7 @@ module Librarian
       end
 
       def implementation(spec)
-        Implementation.new(self, spec, :cyclic => cyclic)
+        Implementation.new(self, spec, cyclic: cyclic)
       end
     end
   end
